aboutsummaryrefslogtreecommitdiff
path: root/video/flic_decoder.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'video/flic_decoder.cpp')
-rw-r--r--video/flic_decoder.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/video/flic_decoder.cpp b/video/flic_decoder.cpp
index 34b667234a..347eae4034 100644
--- a/video/flic_decoder.cpp
+++ b/video/flic_decoder.cpp
@@ -29,7 +29,7 @@
#include "common/endian.h"
#include "common/system.h"
-namespace Graphics {
+namespace Video {
FlicDecoder::FlicDecoder() {
_paletteChanged = false;
@@ -194,7 +194,7 @@ void FlicDecoder::decodeDeltaFLC(uint8 *data) {
#define PSTAMP 18
#define FRAME_TYPE 0xF1FA
-const Surface *FlicDecoder::decodeNextFrame() {
+const Graphics::Surface *FlicDecoder::decodeNextFrame() {
// Read chunk
uint32 frameSize = _fileStream->readUint32LE();
uint16 frameType = _fileStream->readUint16LE();
@@ -320,4 +320,4 @@ void FlicDecoder::copyDirtyRectsToBuffer(uint8 *dst, uint pitch) {
_dirtyRects.clear();
}
-} // End of namespace Graphics
+} // End of namespace Video